@@ -1,12 +1,13 @@
 import datetime
 import json
 import os
+
 from .utils import (
-    suck_out_editions,
     names_to_abbreviations,
-    suck_out_variations_only,
-    suck_out_formats,
     process_variables,
+    suck_out_editions,
+    suck_out_formats,
+    suck_out_variations_only,
 )
 
 
@@ -30,7 +31,7 @@ with open(os.path.join(db_root, "data", "case_name_abbreviations.json")) as f:
     CASE_NAME_ABBREVIATIONS = json.load(f)
 
 
-with open(os.path.join(db_root, "data", "laws.json")) as f:
+with open(os.path.join(db_root, "data", "laws.json"), encoding="utf-8") as f:
     LAWS = json.load(f, object_hook=datetime_parser)
 
 
